.. image:: https://secure.travis-ci.org/cobrateam/splinter.svg?branch=master
   :target: http://travis-ci.org/cobrateam/splinter


++++++++++++++++++++++++++++++++++++++++++++++++
wood-splinter - python tool for test web applications (splinter fork)
++++++++++++++++++++++++++++++++++++++++++++++++

wood-splinter is a fork of splinter.

splinter is a tool for test web applications with a simple for find elements, form actions, and others browser actions.

`what's new in splinter? <https://splinter.readthedocs.io/en/latest/news.html>`_

first steps
===========

* `Installation <https://splinter.readthedocs.io/en/latest/install.html>`_
* `Quick tutorial <https://splinter.readthedocs.io/en/latest/tutorial.html>`_

splinter open source project
============================

* `Community <https://splinter.readthedocs.io/en/latest/community.html>`_
* `Contribute <https://splinter.readthedocs.io/en/latest/contribute.html>`_

documentation
=============

`splinter documentation <https://splinter.readthedocs.io>`_

external links
==============

`Django Full Stack Testing and BDD with Lettuce and Splinter <http://cilliano.com/blog/2011/02/07/django-bdd-with-lettuce-and-splinter/>`_

`Splinter: Python tool for acceptance tests on web applications <http://www.franciscosouza.com/2011/05/splinter-python-tool-for-acceptance-tests-on-web-applications/>`_

`Testes de aceitação com Lettuce e Splinter (pt-br) <http://www.slideshare.net/franciscosouza/testes-de-aceitao-com-lettuce-e-splinter?from=ss_embed>`_

`salad <https://github.com/salad/salad>`_, a nice mix of great BDD ingredients (splinter + `lettuce <http://lettuce.it>`_ integration)

`behave-django <https://github.com/mixxorz/behave-django>`_, BDD testing in Django using `Behave <http://pythonhosted.org/behave/>`_. Works well with splinter.
